@@ -1,5 +1,5 @@
 from PyQt6.QtCore import Qt, QObject, QEvent, QSize
-from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox
+from PyQt6.QtWidgets import QWidget, QVBoxLayout, QHBoxLayout, QLabel, QPushButton, QLineEdit, QComboBox, QDialog, QToolButton, QWidgetAction, QCheckBox, QTableWidget, QHeaderView
 from PyQt6.QtGui import QIcon
 import re
 import requests
@@ -253,12 +253,9 @@ def create_text_box(
         toggle_text_visibility_action.setDefaultWidget(toggle_text_visibility_button)
         style_sheet = f"""
             QToolButton {{
-                border: none;
-                margin-right: 10px;
-            }}
-            QToolButton:hover, QToolButton:pressed {{
                 background-color: transparent;
                 border: none;
+                margin-right: 10px;
             }}
         """
         toggle_text_visibility_button.setStyleSheet(style_sheet)
@@ -363,20 +360,20 @@ def create_checkbox(
     font_size = 14,
     font_color = "#ffffff",
     background_color = "#1e1e1e",
-    padding = 15,
+    padding = 5,
     indicator_background_color = "#1e1e1e",
     indicator_border_width = 1,
     indicator_border_color = "#5c5c5c",
-    indicator_border_radius = 100,
+    indicator_border_radius = 8,
     hover_indicator_background_color = "#333333",
     hover_indicator_border_width = 2,
     hover_indicator_border_color = "#777777",
     pressed_indicator_background_color = "#4a4a4a",
     pressed_indicator_border_width = 2,
     pressed_indicator_border_color = "#0078d7",
-    checked_indicator_background_color = "#0078d7",
-    checked_indicator_border_width = 2,
-    checked_indicator_border_color = "#ffffff",
+    checked_indicator_background_color = "#ffffff",
+    checked_indicator_border_width = 1,
+    checked_indicator_border_color = "#5c5c5c",
     disabled_font_color = "#888888",
     disabled_background_color = "#2d2d2d",
     disabled_border_width = 1,
@@ -392,6 +389,9 @@ def create_checkbox(
             padding: {padding}px;
         }}
         QCheckBox::indicator {{
+            image: none;
+            width: {font_size}px;
+            height: {font_size}px;
             background-color: {indicator_background_color};
             border: {indicator_border_width}px solid {indicator_border_color};
             border-radius: {indicator_border_radius}px;
@@ -408,8 +408,10 @@ def create_checkbox(
             background-color: {checked_indicator_background_color};
             border: {checked_indicator_border_width}px solid {checked_indicator_border_color};
         }}
-        QCheckBox::indicator:disabled {{
+        QCheckBox:disabled {{
             color: {disabled_font_color};
+        }}
+        QCheckBox::indicator:disabled {{
             background-color: {disabled_background_color};
             border: {disabled_border_width}px solid {disabled_border_color};
         }}
@@ -458,6 +460,7 @@ def create_information_message_box(
     message_box = QDialog()
     message_box.setObjectName("message_box")
     message_box.setWindowFlags(Qt.WindowType.FramelessWindowHint)
+    message_box.setMinimumWidth(240)
     message_box.setMaximumWidth(480)
     style_sheet = f"""
         QDialog#message_box {{
@@ -550,6 +553,7 @@ def create_confirmation_message_box(
     confirm_message_box = QDialog()
     confirm_message_box.setObjectName("confirm_message_box")
     confirm_message_box.setWindowFlags(Qt.WindowType.FramelessWindowHint)
+    confirm_message_box.setMinimumWidth(240)
     confirm_message_box.setMaximumWidth(480)
     style_sheet = f"""
         QDialog#confirm_message_box {{
@@ -628,6 +632,122 @@ def create_confirmation_message_box(
     decline_button.clicked.connect(confirm_message_box.reject)
     return confirm_message_box
 
+def create_list_table(
+    items_data,
+    column_headers,
+    column_proportions,
+    row_populator_function,
+    font_family = "Segoe UI",
+    font_size = 14,
+    font_color = "#ffffff",
+    background_color = "#1e1e1e",
+    border_width = 2,
+    border_color = "#5c5c5c",
+    item_font_color = "#ffffff",
+    item_background_color = "#1e1e1e",
+    selected_item_background_color = "#0078d7",
+    header_font_family = "Segoe UI",
+    header_font_size = 14,
+    header_font_color = "#ffffff",
+    header_font_weight = "bold",
+    header_background_color = "#1e1e1e",
+    header_border_width = 1,
+    header_border_color = "#1e1e1e",
+    hover_header_background_color = "#333333",
+    hover_header_border_width = 3,
+    hover_header_border_color = "#777777",
+    pressed_header_background_color = "#4a4a4a",
+    pressed_header_border_width = 3,
+    pressed_header_border_color = "#0078d7",
+    scrollbar_background_color = "#1e1e1e",
+    scrollbar_handle_background_color = "#333333",
+    hover_scrollbar_handle_background_color = "#4a4a4a",
+    hover_scrollbar_handle_border_width = 3,
+    hover_scrollbar_handle_border_color = "#777777",
+    pressed_scrollbar_handle_background_color = "#4a4a4a",
+    pressed_scrollbar_handle_border_width = 3,
+    pressed_scrollbar_handle_border_color = "#0078d7"
+):
+    list_table = QTableWidget()
+    list_table.verticalHeader().setVisible(False)
+    list_table.setColumnCount(len(column_headers))
+    list_table.setHorizontalHeaderLabels(column_headers)
+    header = list_table.horizontalHeader()
+    header.setSectionResizeMode(QHeaderView.ResizeMode.Interactive)
+    
+    def resize_columns():
+        total_width = list_table.viewport().width()
+        if total_width == 0: return
+        for i, proportion in enumerate(column_proportions):
+            list_table.setColumnWidth(i, int(total_width * proportion))
+    
+    resize_columns()
+    original_resize_event = list_table.resizeEvent
+
+    def on_resize(event):
+        resize_columns()
+        if original_resize_event: original_resize_event(event)
+    
+    list_table.resizeEvent = on_resize
+    style_sheet = f"""
+        QTableWidget {{
+            color: {font_color};
+            background-color: {background_color};
+            font-family: {font_family};
+            font-size: {font_size}px;
+            border: {border_width}px solid {border_color};
+        }}
+        QTableWidget::item {{
+            color: {item_font_color};
+            background-color: {item_background_color};
+            border: none;
+        }}
+        QTableWidget::item:selected {{
+            background-color: {selected_item_background_color};
+        }}
+        QHeaderView::section {{
+            color: {header_font_color};
+            background-color: {header_background_color};
+            font-family: {header_font_family};
+            font-size: {header_font_size}px;
+            font-weight: {header_font_weight};
+            border: {header_border_width}px solid {header_border_color};
+        }}
+        QHeaderView::section:hover {{
+            background-color: {hover_header_background_color};
+            border: {hover_header_border_width}px solid {hover_header_border_color};
+        }}
+        QHeaderView::section:pressed {{
+            background-color: {pressed_header_background_color};
+            border: {pressed_header_border_width}px solid {pressed_header_border_color};
+        }}
+        QScrollBar:vertical {{
+            background-color: {scrollbar_background_color};
+            border: none;
+        }}
+        QScrollBar::handle:vertical {{
+            background-color: {scrollbar_handle_background_color};
+            border: none;
+        }}
+        QScrollBar::handle:vertical:hover {{
+            background-color: {hover_scrollbar_handle_background_color};
+            border: {hover_scrollbar_handle_border_width}px solid {hover_scrollbar_handle_border_color};
+        }}
+        QScrollBar::handle:vertical:pressed {{
+            background-color: {pressed_scrollbar_handle_background_color};
+            border: {pressed_scrollbar_handle_border_width}px solid {pressed_scrollbar_handle_border_color};
+        }}
+    """
+    list_table.setStyleSheet(style_sheet)
+    list_table.setRowCount(len(items_data))
+    for row, item_data in enumerate(items_data):
+        items = row_populator_function(item_data)
+        for item in items:
+            item.setTextAlignment(Qt.AlignmentFlag.AlignCenter)
+        for column, item in enumerate(items):
+            list_table.setItem(row, column, item)
+    return list_table
+
 def confirm_exit(
     window,
     background_color = "#1e1e1e",
